@@ -2,8 +2,8 @@ function init(basePath) {
     var action = new RGuiAction(qsTranslate("Copy", "&Copy"), RMainWindowQt.getMainWindow());
     action.setRequiresDocument(true);
     action.setRequiresSelection(true);
+    action.setAllowInterrupt();
     action.setScriptFile(basePath + "/Copy.js");
-    action.setIcon(basePath + "/Copy.svg");
     action.setDefaultShortcuts([
         new QKeySequence(QKeySequence.Copy),
         new QKeySequence("c,p")
