@@ -238,10 +238,15 @@
 <context>
     <name>REntity</name>
     <message>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+98"/>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+100"/>
         <source>Referenced Block</source>
         <translation>Bloco referenciado</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>External Reference</source>
+        <translation>Referência externa</translation>
+    </message>
     <message>
         <location line="+1"/>
         <location line="+1"/>
@@ -253,7 +258,7 @@
         <translation>Posição</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+69"/>
+        <location filename="../src/core/RBlock.cpp" line="+75"/>
         <source>Pixel Unit</source>
         <translation>Pixel unidade</translation>
     </message>
@@ -321,6 +326,11 @@
         <source>Owned by Reference</source>
         <translation>Propriedade da Referência</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>External reference</source>
+        <translation>Referência externa</translation>
+    </message>
     <message>
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
         <location line="+1"/>
@@ -623,7 +633,7 @@
         <translation>ID da camada</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="-7"/>
+        <location filename="../src/core/RBlock.cpp" line="-8"/>
         <location filename="../src/core/RLayer.cpp" line="-8"/>
         <location filename="../src/core/RLayerState.cpp" line="+46"/>
         <location filename="../src/core/RLayout.cpp" line="-24"/>
@@ -711,7 +721,7 @@
         <translation>Extensões máximos</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceData.cpp" line="+886"/>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
         <source>Circular (recursive) block referencing detected:</source>
         <translation>Foi detectada uma referência de bloco circular (recursiva):</translation>
     </message>
@@ -1055,6 +1065,21 @@
         <source>Fenceline 2</source>
         <translation>Linha de Cerca 2</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 1</source>
+        <translation>Ponto 1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 2</source>
+        <translation>Ponto 2</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Plant</source>
+        <translation>Planta</translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Water</source>
@@ -1245,4 +1270,3 @@
     </message>
 </context>
 </TS>
-
